Index: chrome/common/automation_messages.h |
diff --git a/chrome/test/automation/automation_messages.h b/chrome/common/automation_messages.h |
similarity index 95% |
rename from chrome/test/automation/automation_messages.h |
rename to chrome/common/automation_messages.h |
index bb6d8669e0bdf6e67e72f22a642d645bcc6bc4d0..b4b22cde0b8de380fec608560004d2b63e132ce8 100644 |
--- a/chrome/test/automation/automation_messages.h |
+++ b/chrome/common/automation_messages.h |
@@ -2,21 +2,20 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__ |
-#define CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__ |
+#ifndef CHROME_COMMON_AUTOMATION_MESSAGES_H__ |
+#define CHROME_COMMON_AUTOMATION_MESSAGES_H__ |
#pragma once |
#include <string> |
#include "base/basictypes.h" |
-#include "chrome/browser/tab_contents/navigation_entry.h" |
-#include "chrome/browser/tab_contents/security_style.h" |
+#include "chrome/common/automation_constants.h" |
#include "chrome/common/common_param_traits.h" |
-#include "chrome/test/automation/automation_constants.h" |
+#include "chrome/common/page_type.h" |
+#include "chrome/common/security_style.h" |
#include "gfx/rect.h" |
#include "net/base/upload_data.h" |
- |
struct AutomationMsg_Find_Params { |
// Unused value, which exists only for backwards compat. |
int unused; |
@@ -199,8 +198,8 @@ struct ParamTraits<SecurityStyle> { |
}; |
template <> |
-struct ParamTraits<NavigationEntry::PageType> { |
- typedef NavigationEntry::PageType param_type; |
+struct ParamTraits<PageType> { |
+ typedef PageType param_type; |
static void Write(Message* m, const param_type& p) { |
m->WriteInt(p); |
} |
@@ -208,19 +207,19 @@ struct ParamTraits<NavigationEntry::PageType> { |
int type; |
if (!m->ReadInt(iter, &type)) |
return false; |
- *p = static_cast<NavigationEntry::PageType>(type); |
+ *p = static_cast<PageType>(type); |
return true; |
} |
static void Log(const param_type& p, std::string* l) { |
std::string control; |
switch (p) { |
- case NavigationEntry::NORMAL_PAGE: |
+ case NORMAL_PAGE: |
control = "NORMAL_PAGE"; |
break; |
- case NavigationEntry::ERROR_PAGE: |
+ case ERROR_PAGE: |
control = "ERROR_PAGE"; |
break; |
- case NavigationEntry::INTERSTITIAL_PAGE: |
+ case INTERSTITIAL_PAGE: |
control = "INTERSTITIAL_PAGE"; |
break; |
default: |
@@ -520,7 +519,7 @@ struct ParamTraits<NavigationInfo> { |
}; |
// A stripped down version of ContextMenuParams in webkit/glue/context_menu.h. |
-struct ContextMenuParams { |
+struct MiniContextMenuParams { |
// The x coordinate for displaying the menu. |
int screen_x; |
@@ -548,10 +547,10 @@ struct ContextMenuParams { |
GURL frame_url; |
}; |
// Traits for ContextMenuParams structure to pack/unpack. |
template <> |
-struct ParamTraits<ContextMenuParams> { |
- typedef ContextMenuParams param_type; |
+struct ParamTraits<MiniContextMenuParams> { |
+ typedef MiniContextMenuParams param_type; |
static void Write(Message* m, const param_type& p) { |
WriteParam(m, p.screen_x); |
WriteParam(m, p.screen_y); |
@@ -639,7 +638,7 @@ struct ParamTraits<AttachExternalTabParams> { |
} // namespace IPC |
#define MESSAGES_INTERNAL_FILE \ |
- "chrome/test/automation/automation_messages_internal.h" |
+ "chrome/common/automation_messages_internal.h" |
#include "ipc/ipc_message_macros.h" |
-#endif // CHROME_TEST_AUTOMATION_AUTOMATION_MESSAGES_H__ |
+#endif // CHROME_COMMON_AUTOMATION_MESSAGES_H__ |
@@ -548,10 +547,10 @@ struct ContextMenuParams { |
GURL frame_url; |
}; |
-// Traits for ContextMenuParams structure to pack/unpack. |
+// Traits for MiniContextMenuParams structure to pack/unpack. |
template <> |